package higher
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module HigherSource
Operations on newtypes
Type expression application.
Construct a newtype for a type constructor with no parameters.
Construct a newtype for a type constructor with one parameter.
Construct a newtype for a type constructor with two parameters.
Construct a newtype for a type constructor with three parameters.
Construct a newtype for a type constructor with four parameters.
Construct a newtype for a type constructor with five parameters.
Construct a newtype for a type constructor with six parameters.